const path = require("path");
const AdmZip = require("adm-zip");
// const { build } = require("vite");
const getSize = require("get-folder-size");
const templates = require("../lib/templates");

const reportSize = (p, i) =>
    new Promise((resolve, reject) =>
        getSize(p, i, (e, size) => {
            if (e) {
                return reject(e);
            }
            return resolve((size / 1024).toFixed(2));
        })
    );

const BUILD_DIR = "dist";

const build = async () => {
    // TODO: implement the build...
};

const buildTemplate = async (root) => {
    try {
        await build({
            root,
            base: "./",
        });
        const buildDirPath = path.resolve(root, BUILD_DIR);
        const zipPath = path.resolve(root, "dist.zip");
        const zip = new AdmZip();
        zip.addLocalFolder(buildDirPath);
        zip.writeZip(zipPath);

        const [srcSize, buildSize, zipSize] = await Promise.all([
            reportSize(root, /((^|\/)dist*.)|((^|\/)\.)/),
            reportSize(buildDirPath),
            reportSize(zipPath),
        ]);

        // eslint-disable-next-line no-console
        console.log(
            `📝 src ${srcSize}kb 📦 build ${buildSize}kb 🗜️ zip ${zipSize}kb`
        );
    } catch (e) {
        // eslint-disable-next-line no-console
        console.error("Build Failed", e);
    }
};

const hoxtonBuild = async () => {
    const list = templates
        .list()
        .map((p) => p.substring(0, p.lastIndexOf("/")));
    for (let i = 0; i < list.length; i += 1) {
        // eslint-disable-next-line no-await-in-loop
        await buildTemplate(list[i]);
    }
};

module.exports = hoxtonBuild;
