const { Readable } = require("stream");

/**
 * From: https://github.com/vitejs/vite/blob/a47429dabea12e8aa5f4a21209846aaf857d5be0/src/node/utils/fsUtils.ts#L73
 *
 * Read already set body on a Koa context and normalize it into a string.
 * Useful in post-processing middlewares.
 *
 * @param {Readable | Buffer | String | null} stream the response body
 * @returns {Promise<string | null>} the normalised body
 */
module.exports = async function readBody(stream) {
    if (stream instanceof Readable) {
        return new Promise((resolve, reject) => {
            let res = "";
            stream
                .on("data", (chunk) => {
                    res += chunk;
                })
                .on("error", reject)
                .on("end", () => {
                    resolve(res);
                });
        });
    }
    return !stream || typeof stream === "string" ? stream : stream.toString();
};
