const debug = require("debug")("hoxtoncli:api:templates");
const path = require("path");
const Router = require("koa-router");
const templates = require("../../lib/templates");

/**
 * List all of the template files found in the directory
 *
 * @param {Koa.Context} ctx
 */
const listTemplates = async (ctx) => {
    try {
        const cwd = process.cwd();
        const templateList = await templates.list();
        debug("Template files found:", templateList);

        const templateEntries = templateList.map((templatePath) => ({
            path: path.relative(cwd, templatePath),
        }));
        debug("Template entries to return: ", templateEntries);

        ctx.status = 200;
        ctx.body = {
            status: "success",
            data: {
                templates: templateEntries,
            },
        };
    } catch (err) {
        debug("Error", err);
        ctx.status = 500;
    }
};

// Create the routes for the API
const router = new Router();
router.get("/", listTemplates);

module.exports = { router };
