const { insertAt } = require("posthtml-insert-at");

/**
 * Injects document.domain into the head of the index.html file so
 * that we can allow cross-origin iframe access when using hoxton.co/sandbox
 *
 * @param {PostHTML.PostHTML} posthtmlInstance the instance of posthtml to work with
 * @returns {PostHTML.PostHTML}
 */
const injectDocumentDomain = (posthtmlInstance) => {
    const injectText = `
<script>
    // Script injected by Hoxton Dev Server
    document.domain = 'hoxton.co';
</script>
`;
    posthtmlInstance.use(
        insertAt({
            selector: "head",
            append: injectText,
        })
    );

    return posthtmlInstance;
};

module.exports = {
    injectDocumentDomain,
};
