const debug = require("debug")("hoxtoncli:inject");
const posthtml = require("posthtml");
const { injectDocumentDomain } = require("./domain");
const { startLiveReloadServer, injectLiveReload } = require("./livereload");
const { getExternalManifest, injectExternalManifest } = require("./manifest");
const readBody = require("../../lib/readBody");

const matchIndexFile = (ctx) => {
    return !ctx.path.includes("/assets/") && ctx.path.endsWith("index.html");
};

class Inject {
    middleware(config) {
        // Start the CLI server as local-web-sever is preparing middleware and noy on every request
        const { port } = startLiveReloadServer(config);
        debug(`live reload server started`);

        // This is the middleware which runs on each HTTP request
        return async (ctx, next) => {
            // Only process the injections if we are handling an index.html
            if (!matchIndexFile(ctx)) {
                debug(`(skipped) ${ctx.path} is not a candidate for injection`);
                // Process all of the other middlewares
                await next();
                return;
            }

            // Convert POST to GET so that koa-static will still read the files
            if (ctx.method === "POST") {
                ctx.method = "GET";
                debug(`${ctx.path} converted POST to GET`);
            }

            // Process all of the other middlewares
            await next();

            debug(`${ctx.path} processing injections`);

            // Prepare transformations
            const ph = posthtml();

            // Inject live reload script
            injectLiveReload(ph, port);
            debug(`${ctx.path} injecting live reload`);

            // Inject the domain
            injectDocumentDomain(ph);
            debug(`${ctx.path} injecting document.domain`);

            // Inject the manifest
            const manifest = await getExternalManifest(ctx);
            if (manifest) {
                injectExternalManifest(ph, manifest);
                debug(`${ctx.path} injecting manifest`);
            }

            // Get the HTML to amend
            const body = await readBody(ctx.body);
            // Process it
            const result = await ph.process(body);
            // Set the HTML as the response
            ctx.body = result.html;
            ctx.type = "text/html";

            debug(`${ctx.path} injection complete`);
        };
    }
}

module.exports = Inject;
